@@ -1,9 +1,12 @@
 """Webservice for single_wf_snip_analysis (Explore a single waveform with slang)"""
 
 import base64
+import json
 
-from flask import jsonify
+import numpy as np
 from numpy import ndarray, array, frombuffer, ceil
+from flask import jsonify
+
 import soundfile as sf
 
 from py2api.constants import _ARGNAME, _ELSE
@@ -15,6 +18,25 @@ from py2api.py2rest.app_maker import mk_app, dflt_run_app_kwargs
 from peruse.single_wf_snip_analysis import TaggedWaveformAnalysis, DFLT_TILE_SIZE, DFLT_CHK_SIZE, DFLT_SR, LDA
 
 
+class NpEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, np.integer):
+            return int(obj)
+        elif isinstance(obj, np.floating):
+            return float(obj)
+        elif isinstance(obj, np.ndarray):
+            return obj.tolist()
+        else:
+            return super(NpEncoder, self).default(obj)
+
+
+np_encode = NpEncoder().encode
+
+
+def to_jdict(obj):
+    return json.loads(np_encode(obj))
+
+
 def ensure_array(x):
     if not isinstance(x, ndarray):
         return array(x)
@@ -111,7 +133,7 @@ class TaggedWaveformAnalysisForWS(TaggedWaveformAnalysis):
         if self.snips is not None:  # TODO: Should be a web service concern!
             if isinstance(self.snips, ndarray):
                 self.snips = self.snips.tolist()
-        return self.get_attr_jdict(self.on_fit_return_attr)
+        return to_jdict(self.get_attr_jdict(self.on_fit_return_attr))
 
 
 # permissions ##########################################################################################################
@@ -132,7 +154,7 @@ input_trans = InputTrans(
         }
     })
 
-output_trans = OutputTrans({_ELSE: lambda x: jsonify({'_result': x})})
+output_trans = OutputTrans({_ELSE: lambda x: jsonify(x)})
 
 # wrapper ##############################################################################################################
 slang_lite = WebObjWrapper(obj_constructor=TaggedWaveformAnalysisForWS,
